#
# spec file for package libsmbios
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}
%{!?python_sitearch: %global python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib(1))")}

Name:           libsmbios
Version:        2.2.28
Release:        15.4
Summary:        Libraries to get information from standard BIOS tables

License:        GPL-2.0+ or OSL-2.1
Url:            http://linux.dell.com/libsmbios/main/
Group:          System/Management
Source0:        http://linux.dell.com/libsmbios/download/libsmbios/libsmbios-%{version}/%{name}-%{version}.tar.bz2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libcppunit-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  python-base
# Modules: dcdbas.ko
Supplements:    modalias(dmi:*:[bs]vnD[Ee][Ll][Ll]*:*)
# Generated with: extract-modaliases dcdbas
# libsmbios only ever makes sense on intel compatible arches, no DMI tables on ppc, s390, etc.
ExclusiveArch:  ia64 %{ix86} x86_64

%description
Libsmbios is a library and utilities that can be used by client programs
to get information from standard BIOS tables, such as the SMBIOS table.

%package devel
Summary:        Development files for libsmios
License:        GPL-2.0+ or OSL-2.1
Group:          Development/Libraries/C and C++
Requires:       libsmbios2 = %{version}
Requires:       libstdc++-devel

%description devel
Libsmbios is a library and utilities that can be used by client programs to get
information from standard BIOS tables, such as the SMBIOS table.

This package contains the necessary files to compile new client programs
against libsmbios.

%package -n libsmbios2
Summary:        Libraries to get information from standard BIOS tables
License:        GPL-2.0+ or OSL-2.1
Group:          System/Management
Supplements:    modalias(dmi:*:[bs]vnD[Ee][Ll][Ll]*:*)

%description -n libsmbios2
Libsmbios is a library and utilities that can be used by client programs
to get information from standard BIOS tables, such as the SMBIOS table.

%package -n python-smbios
Summary:        Python interface to Libsmbios C library
License:        GPL-2.0+ or OSL-2.1
Group:          Development/Libraries/Python
Requires:       libsmbios2 = %{version}
Supplements:    modalias(dmi:*:[bs]vnD[Ee][Ll][Ll]*:*)
%if %{?suse_version: 0%{?suse_version} > 1110} %{!?suse_version:1}
BuildArch:      noarch
%endif

%description -n python-smbios
This package provides a Python interface to libsmbios.

%package -n smbios-utils-bin
Summary:        Binary utilities that use libsmbios
License:        GPL-2.0+ or OSL-2.1
Group:          System/Management
Supplements:    modalias(dmi:*:[bs]vnD[Ee][Ll][Ll]*:*)
# libsmbios-unsupported-bin was last used in openSUSE 11.4 (libsmbios-unsupported-bin-2.0.2)
Obsoletes:      libsmbios-unsupported-bin <= 2.0.2
Provides:       libsmbios-unsupported-bin = %{version}

%description -n smbios-utils-bin
Get BIOS information, such as System product name, product id, service tag and
asset tag.

%package -n smbios-utils-python
Summary:        Python executables that use libsmbios
License:        GPL-2.0+ or OSL-2.1
Group:          System/Management
Requires:       python-smbios = %{version}
Supplements:    modalias(dmi:*:[bs]vnD[Ee][Ll][Ll]*:*)
# libsmbios-bin was last used in openSUSE 11.4 (libsmbios-bin-2.0.2)
Obsoletes:      libsmbios-bin <= 2.0.2
Provides:       libsmbios-bin = %{version}

%description -n smbios-utils-python
Get BIOS information, such as System product name, product id, service tag and
asset tag. Set service and asset tags on Dell machines. Manipulate wireless
cards/bluetooth on Dell laptops. Set BIOS password on select Dell systems.
Update BIOS on select Dell systems. Set LCD brightness on select Dell laptops.

%package -n yum-dellsysid
Summary:        YUM plugin to retrieve the Dell System ID
License:        GPL-2.0+ or OSL-2.1
Group:          System/Packages
Requires:       smbios-utils-python = %{version}
Requires:       yum

%description -n yum-dellsysid
Libsmbios is a library and utilities that can be used by client programs to get
information from standard BIOS tables, such as the SMBIOS table.

This package contains a YUM plugin which allows the use of certain
substitutions in yum repository configuration files on Dell systems.

%prep
%setup -q

%build
%configure --disable-rpath

make %{?_smp_mflags}

%install
%make_install

# Install headers
install -dp -m 0755 %{buildroot}%{_includedir}
cp -a src/include/* %{buildroot}/%{_includedir}/
cp -a out/public-include/* %{buildroot}/%{_includedir}/
find %{buildroot}/%{_includedir} out/libsmbios_c++ out/libsmbios_c -exec touch -r configure.ac {} \;

# Remove *.la files (package provides pkg-config files), remove static libraries
rm -f %{buildroot}/%{_libdir}/lib*.{la,a}

# Prepare doc files for devel package
mv out/libsmbios_c out/libsmbios_c-%{_arch}
mv out/libsmbios_c++ out/libsmbios_c++-%{_arch}

# Manually install the doc files for the devel package in order to fix duplicates with "fdupes -s"
install -dp -m 0755 %{buildroot}%{_defaultdocdir}/%{name}-devel
cp -a AUTHORS COPYING-GPL COPYING-OSL ChangeLog NEWS README TODO doc/old_news.txt %{buildroot}%{_defaultdocdir}/%{name}-devel/
cp -a src/bin/getopts_LICENSE.txt src/include/smbios/config/boost_LICENSE_1_0_txt %{buildroot}%{_defaultdocdir}/%{name}-devel/
cp -a out/libsmbios_c-%{_arch} %{buildroot}%{_defaultdocdir}/%{name}-devel/
cp -a out/libsmbios_c++-%{_arch} %{buildroot}%{_defaultdocdir}/%{name}-devel/

#
rename libsmbios.mo libsmbios-2.2-x86_64.mo $(find %{buildroot}/%{_datadir} -name libsmbios.mo)

# Remove unneeded locales
%if 0%{?suse_version} &&  0%{?suse_version} < 1140
rm -rf %{buildroot}%{_datadir}/locale/en/
rm -rf %{buildroot}%{_datadir}/locale/en@boldquot/
rm -rf %{buildroot}%{_datadir}/locale/en@quot/
%endif

%find_lang %{name}-2.2-x86_64

# Backwards compatible symlinks
ln -s %{_sbindir}/dellWirelessCtl %{buildroot}%{_bindir}/dellWirelessCtl
ln -s smbios-lcd-brightness %{buildroot}%{_sbindir}/dellLcdBrightness
ln -s smbios-rbu-bios-update %{buildroot}%{_sbindir}/dellBiosUpdate
ln -s smbios-sys-info %{buildroot}%{_sbindir}/getSystemId
ln -s smbios-wireless-ctl %{buildroot}%{_sbindir}/dellWirelessCtl

%fdupes -s %{buildroot}

%clean
rm -rf %{buildroot}

%post -n libsmbios2 -p /sbin/ldconfig

%postun -n libsmbios2 -p /sbin/ldconfig

%files devel
%defattr(-,root,root,-)
%doc %{_defaultdocdir}/%{name}-devel/
%{_includedir}/smbios/
%{_includedir}/smbios_c/
%{_libdir}/libsmbios.so
%{_libdir}/libsmbios_c.so
%{_libdir}/pkgconfig/libsmbios_c*.pc

%files -n libsmbios2 -f %{name}-2.2-x86_64.lang
%defattr(-,root,root,-)
%{_libdir}/libsmbios.so.2*
%{_libdir}/libsmbios_c.so.2*

%files -n python-smbios
%defattr(-,root,root,-)
%doc AUTHORS COPYING-GPL COPYING-OSL ChangeLog NEWS README TODO doc/old_news.txt
%{python_sitelib}/libsmbios_c/

%files -n smbios-utils-bin
%defattr(-,root,root,-)
%doc AUTHORS COPYING-GPL COPYING-OSL ChangeLog NEWS README TODO doc/old_news.txt
%doc doc/pkgheader.sh
%defattr(555,root,root,-)
# legacy C++
%{_sbindir}/dellBiosUpdate-compat
%{_sbindir}/dellLEDCtl
%ifnarch ia64
%{_sbindir}/dellMediaDirectCtl
%endif
# new C utilities
%{_sbindir}/smbios-get-ut-data
%{_sbindir}/smbios-state-byte-ctl
%{_sbindir}/smbios-sys-info-lite
%{_sbindir}/smbios-upflag-ctl

%files -n smbios-utils-python
%defattr(-,root,root,-)
%doc AUTHORS COPYING-GPL COPYING-OSL ChangeLog NEWS README TODO doc/old_news.txt
%dir %{_sysconfdir}/libsmbios
%config(noreplace) %{_sysconfdir}/libsmbios/*
%defattr(555,root,root,-)
# used by HAL in old location, so keep it around until HAL is updated
%{_bindir}/dellWirelessCtl
# python utilities
%{_sbindir}/smbios-lcd-brightness
%{_sbindir}/smbios-passwd
%{_sbindir}/smbios-rbu-bios-update
%{_sbindir}/smbios-sys-info
%{_sbindir}/smbios-token-ctl
%{_sbindir}/smbios-wakeup-ctl
%{_sbindir}/smbios-wireless-ctl
# backwards compatible symlinks
%{_sbindir}/dellBiosUpdate
%{_sbindir}/dellLcdBrightness
%{_sbindir}/dellWirelessCtl
%{_sbindir}/getSystemId
%defattr(-,root,root,-)
%{_datadir}/smbios-utils/

%files -n yum-dellsysid
%defattr(-,root,root,-)
%doc AUTHORS COPYING-GPL COPYING-OSL ChangeLog NEWS README TODO doc/old_news.txt
%dir %{_sysconfdir}/yum
%dir %{_sysconfdir}/yum/pluginconf.d
%config(noreplace) %{_sysconfdir}/yum/pluginconf.d/dellsysid.conf
%dir %{_exec_prefix}/lib/yum-plugins
%{_exec_prefix}/lib/yum-plugins/dellsysid.*

%changelog
* Tue May  8 2012 cfarrell@suse.com
- license update: GPL-2.0+ or OSL-2.1
  SPDX format (http://www.spdx.org/licenses)
* Sun Jul  3 2011 asterios.dramis@gmail.com
- Update to version 2.2.28:
  * Add a couple placeholder files.
  * Don't bail out on exceptions.
  * Don't print out oem strings anymore, print out reseller (oem) id if it is
    different from dell system id.
  * Add public header interface for new oem system id function
    sysinfo_get_dell_oem_system_id().
  * Rework the system id functions to always return Dell system ID for
    sysinfo_get_dell_system_id(), and add a new api to get the OEM ID.
  * Add compiler support up to gcc 4.8.
- Spec file updates:
  * Removed the fix for GCC 4.6 (fixed upstream).
  * Move %%doc files from the library to the other packages.
  * Minor other updates.
* Fri May 13 2011 asterios.dramis@gmail.com
- Update to version 2.2.27:
  * print out all the OEM strings in smbios-sys-info-lite output.
  * fixup logic error in bayonette id detection which could potentially cause
    segfault.
  * Adding support to compile on solaris.
  * update string extracts for spanish.
  * Fix output of translated unicode strings.
  * By default, python was trying to output all translated strings as ascii,
    which breaks for unicode. Wrap sys.stdout with a streamwriter that outputs
    unicode.
  * add spanish translations.
  * localize messages from import/export token dumps.
  * add another exception case for missing header line.
- Spec file updates:
  * Removed Provides/Obsoletes for libsmbios-libs-0.13.12 in libsmbios2
    (0.13.12 was released at 2007-11-02).
  * Removed smbios-utils meta-package (not needed). Provides/Obsoletes for
    libsmbios-bin and libsmbios-unsupported-bin moved to smbios-utils-python
    and smbios-utils-bin respectively.
  * Fix locales removal if suse_version is not set.
  * Minor other updates.
* Tue May 10 2011 crrodriguez@opensuse.org
- Fix build with GCC 4.6
* Fri Mar 18 2011 asterios.dramis@gmail.com
- Update to version 2.2.26:
  * Lots of changes (see ChangeLog).
- Spec file updates:
  * Major changes in subpackages (based on the package spec file and Fedora
    package):
    + Replaced libsmbios-bin and libsmbios-unsupported-bin with
    smbios-utils-bin and smbios-utils-python (added smbios-utils meta-package
    to Obsolete+Provide them).
    + Added python-smbios and yum-dellsysid subpackages.
    + Removed static subpackage.
  * Changes based on rpmdevtools templates and spec-cleaner run.
  * Changed License: to GPLv2+ or OSL 2.1.
  * Updates in Summary:, Url:, Group: and %%description sections.
  * Updates in Buildrequires:, Requires:, Obsoletes: and Provides: sections.
  * Updates in %%prep, %%build and %%install sections.
  * Removed %%define entries, other conditions, etc.
  * Removed support for suse_version < 1100.
  * Various other changes based on the package spec file.
- Fixed rpmlint warning about "files-duplicate".
- Removed the two patches (fixed upstream).
* Wed Oct 28 2009 crrodriguez@opensuse.org
- libsmbios-devel Requires libstdc++-devel
* Mon Mar  2 2009 crrodriguez@suse.de
- fix build with GCC 4.4
* Fri Nov  7 2008 dkukawka@suse.de
- fixed spec:
  - added Supplements: modalias(dmi:*:[bs]vnD[Ee][Ll][Ll]*:*) for
    libsmbios2 and libsmbios-bin to fix bnc#440814
* Wed Aug 13 2008 ro@suse.de
- change ExcludeArch to ExclusiveArch
* Tue Jul 29 2008 coolo@suse.de
- obsolete old name
* Mon Jul  7 2008 dkukawka@suse.de
- change naming of the lib package because of 'Shared Library
  Packaging Policy' and rpmlint
- updated to latest version v2.0.2
* Mon Jun  2 2008 dkukawka@suse.de
- added: 'Supplements: modalias(dmi:*:[bs]vnD[Ee][Ll][Ll]*:*)'
  to specfile to get the package installed on Dell machines
  (fix for bnc#326765)
* Mon Mar 10 2008 crrodriguez@suse.de
- dont buildrequire libxml, only libxml2 is used
* Fri Mar  7 2008 dmueller@suse.de
- fix documentation permissions
* Tue Jan  8 2008 dkukawka@suse.de
- added new patch:
  - libsmbios-fix-compiler_warning_cgcc.diff
* Sat Dec 29 2007 crrodriguez@suse.de
- fix library-without-ldconfig-postun errors
* Wed Dec 19 2007 dkukawka@suse.de
- updated to new version 0.13.13
* Sun Nov  4 2007 dkukawka@suse.de
- updated to new version 0.13.12:
- removed upstream gone patch:
  - libsmbios-fix-includes.diff
- fixed spec-file:
  - binaries moved from /usr/bin to /usr/sbin
* Tue Oct 16 2007 dkukawka@suse.de
- updated to new version 0.13.10:
  - Fix a couple of failure-to-check-return on fopen. most were
    unit-test code only, but two or three were in regular code.
  - Add hinting to the memory class, so that it can intelligently
    close /dev/mem file handle when it is not needed (which is
    most of the time). it only leaves it open when it is scanning,
    so speed is not impacted.
  - new upstream
- added patches:
  - libsmbios-fix-includes.diff: fix missing includes (needed to
    build in beta tree)
* Wed May  2 2007 dkukawka@suse.de
- updated to new version 0.13.6:
  - critical bugfix to dellBiosUpdate utility to fix packet mode
  - autoconf/automake support for automatically building docs
  - more readable 'make' lines by splitting out env vars
  - remove run_cppunit option... always run unit tests.
  - update autoconf/automake utilities to latest version
  - fix LDFLAGS to not overwrite user entered LDFLAGS
  - add automatic doxygen build of docs
  - fix urls of public repos
  - remove yum repo page in favor of official page from docs
  - split dmi table entry point from smbios table entry point
  - support legacy _DMI_ tables
  - fix support for EFI-based imacs without proper _SM_ anchor
* Mon Mar 26 2007 dkukawka@suse.de
- updated to new version 0.13.4 as requested by DELL maintainer
  - autotools conversion
  - new util dellWirelessCtl to control builtin wireless on Dell
    laptops
* Sat Mar  3 2007 dkukawka@suse.de
- fixed spec file: removed 'rm -rf ${RPM_BUILD_ROOT}' from install
  section
- added ExcludeArch for ppc/ppc64 and s390/s390x
* Wed Feb 28 2007 dkukawka@suse.de
- updated to new version 0.12.4:
  * the package no longer provide bios_update_tools subpackage,
    since they are no longer part of the source
* Fri Feb 10 2006 bwise@suse.de
- put description ib bios_update_check
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 19 2006 ro@suse.de
- provide main package name in one subpackage
  (needed for debuginfo since we do not have a main package here)
* Wed Jan 11 2006 bwhiteley@suse.de
- first build
